==> grapesjs-0.17.3.tgz: package/src/i18n/locale/tr.js <==
export default {
  assetManager: {
    addButton: 'Görsel Ekle',
    modalTitle: 'Görsel Seçin',
    uploadTitle: 'Dosya yüklemek için buraya sürükleyin veya tıklayın'
  },
  deviceManager: {
    device: 'Cihaz',
    devices: {
      desktop: 'Masaüstü',
      tablet: 'Tablet',
      mobileLandscape: 'Mobil Yatay',
      mobilePortrait: 'Mobil Dikey'
    }
  },
  panels: {
    buttons: {
      titles: {
        preview: 'Önizleme',
        fullscreen: 'Tam Ekran',
        'sw-visibility': 'Bileşenleri Göster',
        'export-template': 'Kodu Göster',
        'open-sm': 'Stil Düzenleyiciyi Aç',
        'open-tm': 'Ayarlar',
        'open-layers': 'Katmanlar',
        'open-blocks': 'Bloklar'
      }
    }
  },
  selectorManager: {
    selected: 'Seçili',
    emptyState: '- DURUM -',
    label: 'Sınıflar'
  },
  styleManager: {
    empty: 'Stilini düzenlemek istediğiniz öğeyi seçiniz',
    layer: 'Katman',
    sectors: {
      general: 'Genel',
      layout: 'Düzen',
      typography: 'Tipografi',
      decorations: 'Dekorasyon',
      extra: 'Ekstra',
      flex: 'Flex',
      dimension: 'Boyut'
    },
    properties: {
      float: 'Kaydır',
      display: 'Görünüm',
      position: 'Pozisyon',
      top: 'Üst',
      right: 'Sağ',
      left: 'Sol',
      bottom: 'Alt',
      width: 'Genişlik',
      height: 'Yükseklik',
      'max-width': 'Maks. Genişlik',
      'max-height': 'Maks. Yükseklik',
      margin: 'Margin',
      'margin-top': 'Margin Üst',
      'margin-right': 'Margin Sağ',
      'margin-left': 'Margin Sol',
      'margin-bottom': 'Margin Alt',
      padding: 'Padding',
      'padding-top': 'Padding Üst',
      'padding-left': 'Padding Sol',
      'padding-right': 'Padding Sağ',
      'padding-bottom': 'Padding Alt',
      'font-family': 'Font Tipi',
      'font-size': 'Font Boyutu',
      'font-weight': 'Font Kalınlığı',
      'letter-spacing': 'Harf Boşluğu',
      color: 'Renk',
      'line-height': 'Satır Boşluğu',
      'text-align': 'Yazı Hizalaması',
      'text-shadow': 'Yazı Gölgesi',
      'text-shadow-h': 'Yazı Gölgesi - Yatay',
      'text-shadow-v': 'Yazı Gölgesi - Dikey',
      'text-shadow-blur': 'Yazı Gölgesi Bulanıklığı',
      'text-shadow-color': 'Yazı Gölgesi Rengi',
      'border-top-left': 'Kenar Üst Sol',
      'border-top-right': 'Kenar Üst Sağ',
      'border-bottom-left': 'Kenar Alt Sol',
      'border-bottom-right': 'Kenar Alt Sağ',
      'border-radius-top-left': 'Köşe Yumuşuması Üst Sol',
      'border-radius-top-right': 'Köşe Yumuşuması Üst Sağ',
      'border-radius-bottom-left': 'Köşe Yumuşuması Alt Sol',
      'border-radius-bottom-right': 'Köşe Yumuşuması Alt Sağ',
      'border-radius': 'Köşe Yumuşaması',
      border: 'Kenar',
      'border-width': 'Kenar Kalınlığı',
      'border-style': 'Kenar Stili',
      'border-color': 'Kenar Rengi',
      'box-shadow': 'Kutu Gölgesi',
      'box-shadow-h': 'Kutu Gölgesi - Yatay',
      'box-shadow-v': 'Kutu Gölgesi - Dikey',
      'box-shadow-blur': 'Kutu Gölgesi Bulanıklığı',
      'box-shadow-spread': 'Kutu Gölgesi Dağılımı',
      'box-shadow-color': 'Kutu Gölgesi Rengi',
      'box-shadow-type': 'Kutu Gölgesi Tipi',
      background: 'Arkaplan',
      'background-image': 'Arkaplan Resmi',
      'background-repeat': 'Arkaplan Tekrarı',
      'background-position': 'Arkaplan Pozisyonu',
      'background-attachment': 'Arkaplan Eklentisi',
      'background-size': 'Arkaplan Boyutu',
      transition: 'Geçiş',
      'transition-property': 'Geçiş Özelliği',
      'transition-duration': 'Geçiş Süresi',
      'transition-timing-function': 'Geçiş Zamanlaması Metodu',
      perspective: 'Perspektif',
      transform: 'Boyutlama',
      'transform-rotate-x': 'Yatay Yönlendirme',
      'transform-rotate-y': 'Dikey Yönlendirme',
      'transform-rotate-z': 'Hacimsel Yönlendirme',
      'transform-scale-x': 'Dikey Oran',
      'transform-scale-y': 'Yatay Oran',
      'transform-scale-z': 'Hacimsel Oran',
      'flex-direction': 'Flex Yönü',
      'flex-wrap': 'Flex Kesme',
      'justify-content': 'İçeriği Sığdır',
      'align-items': 'Öğeleri Hizala',
      'align-content': 'İçeriği Hizala',
      order: 'Sıra',
      'flex-basis': 'Flex Bazı',
      'flex-grow': 'Flex Büyüme',
      'flex-shrink': 'Flex Küçülme',
      'align-self': 'Kendini Hizala',
      'background-color': 'Arkaplan Rengi'
    }
  },
  traitManager: {
    empty: 'Özelliklerini düzenlemek istediğiniz öğeyi seçiniz',
    label: 'Bileşen Özellikleri',
    traits: {
      labels: {},
      attributes: {},
      options: {}
    }
  }
};

==> grapesjs-0.20.4.tgz: package/src/i18n/locale/tr.js <==
export default {
  assetManager: {
    addButton: 'Görsel Ekle',
    modalTitle: 'Görsel Seçin',
    uploadTitle: 'Dosya yüklemek için buraya sürükleyin veya tıklayın',
  },
  deviceManager: {
    device: 'Cihaz',
    devices: {
      desktop: 'Masaüstü',
      tablet: 'Tablet',
      mobileLandscape: 'Mobil Yatay',
      mobilePortrait: 'Mobil Dikey',
    },
  },
  panels: {
    buttons: {
      titles: {
        preview: 'Önizleme',
        fullscreen: 'Tam Ekran',
        'sw-visibility': 'Bileşenleri Göster',
        'export-template': 'Kodu Göster',
        'open-sm': 'Stil Düzenleyiciyi Aç',
        'open-tm': 'Ayarlar',
        'open-layers': 'Katmanlar',
        'open-blocks': 'Bloklar',
      },
    },
  },
  selectorManager: {
    selected: 'Seçili',
    emptyState: '- DURUM -',
    label: 'Sınıflar',
  },
  styleManager: {
    empty: 'Stilini düzenlemek istediğiniz öğeyi seçiniz',
    layer: 'Katman',
    sectors: {
      general: 'Genel',
      layout: 'Düzen',
      typography: 'Tipografi',
      decorations: 'Dekorasyon',
      extra: 'Ekstra',
      flex: 'Flex',
      dimension: 'Boyut',
    },
    properties: {
      float: 'Kaydır',
      display: 'Görünüm',
      position: 'Pozisyon',
      top: 'Üst',
      right: 'Sağ',
      left: 'Sol',
      bottom: 'Alt',
      width: 'Genişlik',
      height: 'Yükseklik',
      'max-width': 'Maks. Genişlik',
      'max-height': 'Maks. Yükseklik',
      margin: 'Margin',
      'margin-top': 'Margin Üst',
      'margin-right': 'Margin Sağ',
      'margin-left': 'Margin Sol',
      'margin-bottom': 'Margin Alt',
      padding: 'Padding',
      'padding-top': 'Padding Üst',
      'padding-left': 'Padding Sol',
      'padding-right': 'Padding Sağ',
      'padding-bottom': 'Padding Alt',
      'font-family': 'Font Tipi',
      'font-size': 'Font Boyutu',
      'font-weight': 'Font Kalınlığı',
      'letter-spacing': 'Harf Boşluğu',
      color: 'Renk',
      'line-height': 'Satır Boşluğu',
      'text-align': 'Yazı Hizalaması',
      'text-shadow': 'Yazı Gölgesi',
      'text-shadow-h': 'Yazı Gölgesi - Yatay',
      'text-shadow-v': 'Yazı Gölgesi - Dikey',
      'text-shadow-blur': 'Yazı Gölgesi Bulanıklığı',
      'text-shadow-color': 'Yazı Gölgesi Rengi',
      'border-top-left': 'Kenar Üst Sol',
      'border-top-right': 'Kenar Üst Sağ',
      'border-bottom-left': 'Kenar Alt Sol',
      'border-bottom-right': 'Kenar Alt Sağ',
      'border-radius-top-left': 'Köşe Yumuşuması Üst Sol',
      'border-radius-top-right': 'Köşe Yumuşuması Üst Sağ',
      'border-radius-bottom-left': 'Köşe Yumuşuması Alt Sol',
      'border-radius-bottom-right': 'Köşe Yumuşuması Alt Sağ',
      'border-radius': 'Köşe Yumuşaması',
      border: 'Kenar',
      'border-width': 'Kenar Kalınlığı',
      'border-style': 'Kenar Stili',
      'border-color': 'Kenar Rengi',
      'box-shadow': 'Kutu Gölgesi',
      'box-shadow-h': 'Kutu Gölgesi - Yatay',
      'box-shadow-v': 'Kutu Gölgesi - Dikey',
      'box-shadow-blur': 'Kutu Gölgesi Bulanıklığı',
      'box-shadow-spread': 'Kutu Gölgesi Dağılımı',
      'box-shadow-color': 'Kutu Gölgesi Rengi',
      'box-shadow-type': 'Kutu Gölgesi Tipi',
      background: 'Arkaplan',
      'background-image': 'Arkaplan Resmi',
      'background-repeat': 'Arkaplan Tekrarı',
      'background-position': 'Arkaplan Pozisyonu',
      'background-attachment': 'Arkaplan Eklentisi',
      'background-size': 'Arkaplan Boyutu',
      transition: 'Geçiş',
      'transition-property': 'Geçiş Özelliği',
      'transition-duration': 'Geçiş Süresi',
      'transition-timing-function': 'Geçiş Zamanlaması Metodu',
      perspective: 'Perspektif',
      transform: 'Boyutlama',
      'transform-rotate-x': 'Yatay Yönlendirme',
      'transform-rotate-y': 'Dikey Yönlendirme',
      'transform-rotate-z': 'Hacimsel Yönlendirme',
      'transform-scale-x': 'Dikey Oran',
      'transform-scale-y': 'Yatay Oran',
      'transform-scale-z': 'Hacimsel Oran',
      'flex-direction': 'Flex Yönü',
      'flex-wrap': 'Flex Kesme',
      'justify-content': 'İçeriği Sığdır',
      'align-items': 'Öğeleri Hizala',
      'align-content': 'İçeriği Hizala',
      order: 'Sıra',
      'flex-basis': 'Flex Bazı',
      'flex-grow': 'Flex Büyüme',
      'flex-shrink': 'Flex Küçülme',
      'align-self': 'Kendini Hizala',
      'background-color': 'Arkaplan Rengi',
    },
  },
  traitManager: {
    empty: 'Özelliklerini düzenlemek istediğiniz öğeyi seçiniz',
    label: 'Bileşen Özellikleri',
    traits: {
      labels: {},
      attributes: {},
      options: {},
    },
  },
};
